# Sirex
SiRex - Simple Regex - A package to use regex commands on strings using simple function calls


## Usage

Sirex has many functions that help you do  regex function calls on strings  <br>
Please see the documentation for the different functions

Installation 
```
pip install sirex
```

Usage 
```
from sirex import * 
sirex.count_numbers("Hell123ow 123")
```
